import { createProxyAndHandleRequests } from '@adminide-stack/extension-api';
import { URI } from '@vscode-alt/monaco-editor/esm/vs/base/common/uri.js';
import { Subscription, fromEventPattern } from 'rxjs';

class ClientOrganization {
  _contextService;
  subscriptions = new Subscription();
  proxy;
  constructor(connection, _contextService) {
    this._contextService = _contextService;
    this.proxy = createProxyAndHandleRequests('organization', connection, this);
    this._contextService.getCompleteOrganization().then(organization => this.proxy.$acceptOrganizationData(this.getOrganizationData(organization)));
    this.subscriptions.add(fromEventPattern(_contextService.onDidChangeOrganizationResources).subscribe(event => {
      this.proxy.$acceptOrganizationData(this.getOrganizationData(this._contextService.getOrganization()));
    }));
    this.subscriptions.add(fromEventPattern(_contextService.onDidChangeOrganizationName).subscribe(event => {
      this.proxy.$acceptOrganizationData(this.getOrganizationData(this._contextService.getOrganization()));
    }));
    this.subscriptions.add(fromEventPattern(_contextService.onDidChangeApplicationState).subscribe(event => {
      this.proxy.$acceptOrganizationData(this.getOrganizationData(this._contextService.getOrganization()));
    }));
  }
  $checkExists(includes) {
    return null;
  }
  $saveAll(includeUntitled) {
    throw new Error("Method not implemented.");
  }
  $updateOrganizationResources(extensionName, index, deleteCount, resourcesToAdd) {
    resourcesToAdd.map(f => ({
      uri: URI.revive(f.uri),
      name: f.name
    }));
    // this._contextService.updateResources([organizationResourcesToAdd]);
    console.error('(updateOrganizationResources) MEthod not implemented');
    return null;
  }
  $resolveProxy(url) {
    throw new Error("Method not implemented.");
  }
  getOrganizationData(organization) {
    if (this._contextService.getOrganization().id === '') {
      //  empty organization
      return null;
    }
    return {
      configuration: organization.configuration || undefined,
      resources: organization.resources,
      id: organization.id,
      name: organization.name
    };
  }
  unsubscribe() {
    this.subscriptions.unsubscribe();
  }
}

export { ClientOrganization };
//# sourceMappingURL=client-organization.js.map
