import React__default, { useState, useEffect } from 'react';
import { Subscription } from 'rxjs';
import { map } from 'rxjs/operators/index.js';
import { useExtensionController } from '../../epics/load-extension-script.js';
import { ContributableViewContainer } from '@adminide-stack/extension-api';

const ViewComponent = props => {
  const [panelView, setPanelView] = useState(null);
  const controller = useExtensionController();
  const subscriptions = new Subscription();
  useEffect(() => {
    subscriptions.add(controller.services.panelView.getPanelViews(ContributableViewContainer.Panel).pipe(map(views => ({
      views
    }))).subscribe(stateUpdate => {
      const view = stateUpdate.views.find(v => v.id === props.viewId);
      setPanelView(view);
    }));
    return () => {
      subscriptions.unsubscribe();
    };
  }, [props.viewId]);
  if (!(props.viewId && props.visible && panelView)) {
    return null;
  }
  const {
    reactElement,
    id
  } = panelView;
  return React__default.createElement("div", {
    id: id
  }, reactElement ? {
    ...reactElement,
    props: {
      ...reactElement.props,
      ...props.elementProps
    }
  } : null);
};

export { ViewComponent };
//# sourceMappingURL=ViewComponent.js.map
