import { BehaviorSubject } from 'rxjs';
import { CommandRegistry } from './command-service.js';
import { createExtensionsService } from './extensions-service.js';
import { EMPTY_ENVIRONMENT } from '../api/environment.js';
import { editorWindowsService } from './windows-service.js';
import { PanelViewProviderRegistry } from './panel-views.js';

// Function to create the services object
function createServices(platformContext, internalService) {
  // Ensure platformContext and internalService are properly defined
  if (!platformContext || !internalService) {
    throw new Error('platformContext or internalService is missing.');
  }
  // Initialize and return the services object
  return {
    environment: new BehaviorSubject(EMPTY_ENVIRONMENT),
    windows: editorWindowsService(platformContext),
    contextKeyService: internalService.contextKeyService,
    lifecycleService: internalService.lifecycleService,
    model: internalService.model,
    viewer: internalService.viewer,
    extensions: createExtensionsService(platformContext, internalService.model),
    commands: new CommandRegistry(),
    contribution: internalService.contribution,
    panelView: new PanelViewProviderRegistry(),
    organizationContextService: internalService.organizationContextService,
    configurationService: internalService.configurationService,
    registry: internalService.registry,
    preferenceService: internalService.preferenceService,
    // Add any other pending services as needed
    notificationService: internalService.notificationService,
    dialogService: internalService.dialogService,
    statusbarService: internalService.statusbarService,
    keybindingService: internalService.keybindingService
    // More services here...
  };
}

export { createServices };
//# sourceMappingURL=services.js.map
